==> haskell-quickcheck-text-0.1.2.1-137-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-text
version:              0.1.2.1
visibility:           public
id:                   quickcheck-text-0.1.2.1-96w6oxTEJyrAptnXSv2ydO
key:                  quickcheck-text-0.1.2.1-96w6oxTEJyrAptnXSv2ydO
license:              MIT
copyright:            2015-2016 Sharif Olorin and others
maintainer:           sio@tesser.org
author:               Sharif Olorin
homepage:             https://github.com/olorin/quickcheck-text
synopsis:             Alternative arbitrary instance for Text
description:
    The usual Arbitrary instance for Text
    (in
    <https://hackage.haskell.org/package/quickcheck-instances quickcheck-instances>)
    only has single-byte
    instances and so isn'\''t an ideal representation of a valid UTF-8
    character. This package has generators for one-, two- and three-byte
    UTF-8 characters (all that are currently in use).

category:             Text
abi:                  ddf616a40bdb1b4023ee17d009827050
exposed:              True
exposed-modules:      Data.Text.Arbitrary Test.QuickCheck.Utf8
import-dirs:          /usr/lib/ghc-9.2.8/site-local/quickcheck-text-0.1.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/quickcheck-text-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-text
hs-libraries:         HSquickcheck-text-0.1.2.1-96w6oxTEJyrAptnXSv2ydO
depends:
    QuickCheck-2.14.3-1kHSJYV22r9H1CQAFEYDgg base-4.16.4.0
    binary-0.8.9.0 bytestring-0.11.4.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-text/html/quickcheck-text.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-text/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-text-0.1.2.1-138-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-text
version:              0.1.2.1
visibility:           public
id:                   quickcheck-text-0.1.2.1-D3DVnrMtln4AojZ3Mcs6M2
key:                  quickcheck-text-0.1.2.1-D3DVnrMtln4AojZ3Mcs6M2
license:              MIT
copyright:            2015-2016 Sharif Olorin and others
maintainer:           sio@tesser.org
author:               Sharif Olorin
homepage:             https://github.com/olorin/quickcheck-text
synopsis:             Alternative arbitrary instance for Text
description:
    The usual Arbitrary instance for Text
    (in
    <https://hackage.haskell.org/package/quickcheck-instances quickcheck-instances>)
    only has single-byte
    instances and so isn'\''t an ideal representation of a valid UTF-8
    character. This package has generators for one-, two- and three-byte
    UTF-8 characters (all that are currently in use).

category:             Text
abi:                  aaa2ccad0ac58d43c220392e010438ff
exposed:              True
exposed-modules:      Data.Text.Arbitrary Test.QuickCheck.Utf8
import-dirs:          /usr/lib/ghc-9.2.8/site-local/quickcheck-text-0.1.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/quickcheck-text-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-text
hs-libraries:         HSquickcheck-text-0.1.2.1-D3DVnrMtln4AojZ3Mcs6M2
depends:
    QuickCheck-2.14.3-4ByVFEBmTRSJjm02AG2pXb base-4.16.4.0
    binary-0.8.9.0 bytestring-0.11.4.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-text/html/quickcheck-text.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-text/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
